Code of Conduct
===============

Our community is made up of a mixture of professionals and
volunteers from around the world.  We value the participation of
every member of the community and want all participants to have an
enjoyable and fulfilling experience.  Accordingly, all participants
are expected to show respect and courtesy to others.

To make clear what is expected, everyone participating in this
project is expected to follow the Python Software
Foundation’s `Code of Conduct <https://www.python.org/psf/conduct/>`_.

If you believe someone is violating the code of conduct, or have any
other concerns, please contact the maintainers.  We will respect
confidentiality requests for the purpose of protecting victims of
abuse.
